==> kplatforms-6.x-1.0.tar.gz: kplatforms/drupal-patch.sh <==
#!/bin/bash
# This script executes some manual tasks following the installation of a Drupal platform.

#****************************************
# Variables
#****************************************

EXIT_NB=0
THIS_FILE=$(echo $0 | awk -F/ '{print $NF}')
PATH_PLATFORM=$1
DRUPAL_VERSION=6   # Drupal version for which the script is designed.
WWW_DATA=www-data  # use www-data for debian & ubuntu, apache for redhat & centos

#****************************************
# Verifications
#****************************************

case $PATH_PLATFORM in

  # Check if the directory passed as argument is absolute.
  /*)
    # Check if the directory passed as argument does not exist.
    if [ ! -d $PATH_PLATFORM ]; then
      echo
      echo "ERROR: Directory '$PATH_PLATFORM' does not exist."
      echo
      exit 1
    fi
  ;;

  *)
    echo
    echo "ERROR: Directory is missing or is not absolute."
    echo
    echo Usage:
    echo "$THIS_FILE /absolute/path/to/the/platform"
    echo
    exit 1
  ;;

esac

# Check if the platform directory contains the file CHANGELOG.txt
if [ ! -f $PATH_PLATFORM/CHANGELOG.txt ]; then
  echo
  echo "ERROR: Directory '$PATH_PLATFORM' does not contain the file CHANGELOG.txt."
  echo
  exit 1
fi

# Check if the version of Drupal is the one the script is for.
DRUPAL_VERSION_PLATFORM=$(head -n2 $PATH_PLATFORM/CHANGELOG.txt | tail -n1 | awk -F. '{print $1}' | awk '{print $NF}')
if [ "$DRUPAL_VERSION_PLATFORM" != "$DRUPAL_VERSION" ]; then
  echo
  echo "ERROR: The version of Drupal installed in the platform is not the same as the script is expecting."
  echo
  exit 1
fi

#****************************************
# Patching modules
#****************************************

# Boost
# Because of http://drupal.org/node/1118152#comment-4396414 and http://drupal.org/node/1002100
# Manually installing the file "boost/boost.drush.inc" from boost-6.x-1.x-dev.tar.gz:
cd $PATH_PLATFORM/sites/all/modules/contrib/boost && \
  wget -q http://ftp.drupal.org/files/projects/boost-6.x-1.x-dev.tar.gz && \
  tar zxf boost-6.x-1.x-dev.tar.gz && \
  mv boost/boost.drush.inc ./ && \
  rm -r boost boost-6.x-1.x-dev.tar.gz
# Test exit code.
if [ $? -eq 0 ]; then
  echo "OK: Boost patched."
else
  echo "ERROR: Boost not patched."
  EXIT_NB=1
fi

#****************************************
# Patching librairies
#****************************************

# getID3 for the Drupal contrib module "getID3()" (getid3).
rm -r $PATH_PLATFORM/sites/all/libraries/getid3/demos
# Test exit code.
if [ $? -eq 0 ]; then
  echo "OK: getID3's demo files deleted."
else
  echo "ERROR: getID3's demo files not deleted."
  EXIT_NB=1
fi

# jQuery Cycle Plugin for the Drupal contrib module "Views cycle" (views_cycle).
# These is one file into a directory. See "DrushMakeDownload_Get get filename from URL" http://drupal.org/node/763532
mkdir $PATH_PLATFORM/sites/all/libraries/jquery.cycle && \
  cd $PATH_PLATFORM/sites/all/libraries/jquery.cycle && \
  wget -q --no-check-certificate https://www.github.com/downloads/malsup/cycle/jquery.cycle.all.2.88.min.js && \
  mv jquery.cycle.all.2.88.min.js jquery.cycle.all.min.js
# Test exit code.
if [ $? -eq 0 ]; then
  echo "OK: jquery.cycle.all.min.js installed for the module 'Views cycle'."
else
  echo "ERROR: jquery.cycle.all.min.js not installed for the module 'Views cycle'."
  EXIT_NB=1
fi

# Marker clusterer addon by Jef Poskanzer for the Drupal contrib module "GMap Module" (gmap).
# These is one file into a directory. See "DrushMakeDownload_Get get filename from URL" http://drupal.org/node/763532
cd $PATH_PLATFORM/sites/all/modules/contrib/gmap/thirdparty && \
  wget -q http://www.acme.com/javascript/Clusterer2.js
# Test exit code.
if [ $? -eq 0 ]; then
  echo "OK: Marker clusterer addon by Jef Poskanzer installed installed for the module GMap."
else
  echo "ERROR: Marker clusterer addon by Jef Poskanzer installed not installed for the module GMap."
  EXIT_NB=1
fi

# "Portable PHP password hashing framework" (phpass) for the Drupal contrib module "Secure Password Hashes" (phpass).
# These is one file into a directory. See "DrushMakeDownload_Get get filename from URL" http://drupal.org/node/763532
cd $PATH_PLATFORM/sites/all/modules/contrib/phpass && \
  wget -q http://www.openwall.com/phpass/phpass-0.3.tar.gz && \
  tar zxf phpass-0.3.tar.gz && \
  mv phpass-0.3/PasswordHash.php ./ && \
  rm -r phpass-0.3 && \
  rm phpass-0.3.tar.gz && \
  chmod a+r PasswordHash.php
# Test exit code.
if [ $? -eq 0 ]; then
  echo "OK: 'Portable PHP password hashing framework' (phpass) installed for the module 'Secure Password Hashes' (phpass)."
else
  echo "ERROR: 'Portable PHP password hashing framework' (phpass) not installed for the module 'Secure Password Hashes' (phpass)."
  EXIT_NB=1
fi

# SWFUpload for the Drupal contrib module "Image FUpload" (image_fupload).
# "swfupload.swf", "swfupload.js" and "swfupload.queue.js" should be located in "sites/all/modules/contrib/image_fupload/swfupload/"
cd $PATH_PLATFORM/sites/all/modules/contrib/image_fupload/swfupload && \
  cp Flash/swfupload.swf ./ && \
  cp plugins/swfupload.queue.js ./
# Test exit code.
if [ $? -eq 0 ]; then
  echo "OK: SWFUpload files copied for the module 'Image FUpload'."
else
  echo "ERROR: SWFUpload files are not copied for the module 'Image FUpload'."
  EXIT_NB=1
fi

# TCPDF for the Drupal contrib module "Printer, e-mail and PDF versions" (print).
# TCPDF directory Non-writable permissions.
# TODO: Still needed ?
chmod g+w $PATH_PLATFORM/sites/all/libraries/tcpdf/cache $PATH_PLATFORM/sites/all/libraries/tcpdf/images && \
  chgrp $WWW_DATA $PATH_PLATFORM/sites/all/libraries/tcpdf/cache $PATH_PLATFORM/sites/all/libraries/tcpdf/images
# Test exit code.
if [ $? -eq 0 ]; then
  echo "OK: TCPDF chmod and chgrp."
else
  echo "ERROR: TCPDF chmod and chgrp."
  EXIT_NB=1
fi

#****************************************
# Conclusion
#****************************************

if [ $EXIT_NB -eq 0 ]; then
  echo "OK: '$THIS_FILE' terminated successfully."
  exit $EXIT_NB
else
  echo "ERROR: '$THIS_FILE' terminated with error(s)."
  exit $EXIT_NB
fi

#****************************************
# End
#****************************************

==> kplatforms-6.x-1.1.tar.gz: kplatforms/drupal-patch.sh <==
#!/bin/bash
# This script executes some manual tasks following the installation of a Drupal platform.

#****************************************
# Variables
#****************************************

EXIT_NB=0
THIS_FILE=$(echo $0 | awk -F/ '{print $NF}')
PATH_PLATFORM=$1
DRUPAL_VERSION=6   # Drupal version for which the script is designed.
WWW_DATA=www-data  # use www-data for debian & ubuntu, apache for redhat & centos

#****************************************
# Verifications
#****************************************

case $PATH_PLATFORM in

  # Check if the directory passed as argument is absolute.
  /*)
    # Check if the directory passed as argument does not exist.
    if [ ! -d $PATH_PLATFORM ]; then
      echo
      echo "ERROR: Directory '$PATH_PLATFORM' does not exist."
      echo
      exit 1
    fi
  ;;

  *)
    echo
    echo "ERROR: Directory is missing or is not absolute."
    echo
    echo Usage:
    echo "$THIS_FILE /absolute/path/to/the/platform"
    echo
    exit 1
  ;;

esac

# Check if the platform directory contains the file CHANGELOG.txt
if [ ! -f $PATH_PLATFORM/CHANGELOG.txt ]; then
  echo
  echo "ERROR: Directory '$PATH_PLATFORM' does not contain the file CHANGELOG.txt."
  echo
  exit 1
fi

# Check if the version of Drupal is the one the script is for.
DRUPAL_VERSION_PLATFORM=$(head -n2 $PATH_PLATFORM/CHANGELOG.txt | tail -n1 | awk -F. '{print $1}' | awk '{print $NF}')
if [ "$DRUPAL_VERSION_PLATFORM" != "$DRUPAL_VERSION" ]; then
  echo
  echo "ERROR: The version of Drupal installed in the platform is not the same as the script is expecting."
  echo
  exit 1
fi

#****************************************
# Patching librairies
#****************************************

# TCPDF for the Drupal contrib module "Printer, e-mail and PDF versions" (print).
# TCPDF directories non-writable permissions.
chmod g+w $PATH_PLATFORM/sites/all/libraries/tcpdf/cache $PATH_PLATFORM/sites/all/libraries/tcpdf/images && \
  chgrp $WWW_DATA $PATH_PLATFORM/sites/all/libraries/tcpdf/cache $PATH_PLATFORM/sites/all/libraries/tcpdf/images
# Test exit code.
if [ $? -eq 0 ]; then
  echo "OK: TCPDF chmod and chgrp."
else
  echo "ERROR: TCPDF chmod and chgrp."
  EXIT_NB=1
fi

#****************************************
# Conclusion
#****************************************

if [ $EXIT_NB -eq 0 ]; then
  echo "OK: '$THIS_FILE' terminated successfully."
  exit $EXIT_NB
else
  echo "ERROR: '$THIS_FILE' terminated with error(s)."
  exit $EXIT_NB
fi

#****************************************
# End
#****************************************
